@@ -218,7 +218,7 @@ class Post(object):
 
     @property
     def image(self):
-        if not hasattr(self.tim):
+        if not hasattr(self, 'tim'):
             return
 
         img = 'http://i.4cdn.org/{p.board}/{p.tim}{p.ext}'.format(p=self)
